aboutsummaryrefslogtreecommitdiffstats
path: root/vespa-feed-client-api
diff options
context:
space:
mode:
authorjonmv <venstad@gmail.com>2023-01-04 08:53:57 +0100
committerjonmv <venstad@gmail.com>2023-01-04 08:53:57 +0100
commiteb0bf8c5bb18ad89ba03d290c6cedc6773b321bc (patch)
treefb27b08113e31c46015659d89eae0d92230b5711 /vespa-feed-client-api
parentc9746a990c0daf8103dc7a09ab0d80ee87565a3b (diff)
Use --compression gzip instead
Diffstat (limited to 'vespa-feed-client-api')
-rw-r--r--vespa-feed-client-api/abi-spec.json18
-rw-r--r--vespa-feed-client-api/src/main/java/ai/vespa/feed/client/FeedClientBuilder.java6
2 files changed, 22 insertions, 2 deletions
diff --git a/vespa-feed-client-api/abi-spec.json b/vespa-feed-client-api/abi-spec.json
index 137c7f32bfe..64b049dc75d 100644
--- a/vespa-feed-client-api/abi-spec.json
+++ b/vespa-feed-client-api/abi-spec.json
@@ -112,6 +112,23 @@
],
"fields" : [ ]
},
+ "ai.vespa.feed.client.FeedClientBuilder$Compression" : {
+ "superClass" : "java.lang.Enum",
+ "interfaces" : [ ],
+ "attributes" : [
+ "public",
+ "final",
+ "enum"
+ ],
+ "methods" : [
+ "public static ai.vespa.feed.client.FeedClientBuilder$Compression[] values()",
+ "public static ai.vespa.feed.client.FeedClientBuilder$Compression valueOf(java.lang.String)"
+ ],
+ "fields" : [
+ "public static final enum ai.vespa.feed.client.FeedClientBuilder$Compression none",
+ "public static final enum ai.vespa.feed.client.FeedClientBuilder$Compression gzip"
+ ]
+ },
"ai.vespa.feed.client.FeedClientBuilder" : {
"superClass" : "java.lang.Object",
"interfaces" : [ ],
@@ -142,6 +159,7 @@
"public abstract ai.vespa.feed.client.FeedClientBuilder setCaCertificates(java.util.Collection)",
"public abstract ai.vespa.feed.client.FeedClientBuilder setEndpointUris(java.util.List)",
"public abstract ai.vespa.feed.client.FeedClientBuilder setProxy(java.net.URI)",
+ "public abstract ai.vespa.feed.client.FeedClientBuilder setCompression(ai.vespa.feed.client.FeedClientBuilder$Compression)",
"public abstract ai.vespa.feed.client.FeedClient build()"
],
"fields" : [
diff --git a/vespa-feed-client-api/src/main/java/ai/vespa/feed/client/FeedClientBuilder.java b/vespa-feed-client-api/src/main/java/ai/vespa/feed/client/FeedClientBuilder.java
index ca6cd3161ec..d48c3c31348 100644
--- a/vespa-feed-client-api/src/main/java/ai/vespa/feed/client/FeedClientBuilder.java
+++ b/vespa-feed-client-api/src/main/java/ai/vespa/feed/client/FeedClientBuilder.java
@@ -123,8 +123,10 @@ public interface FeedClientBuilder {
/** Specify HTTP(S) proxy for all endpoints */
FeedClientBuilder setProxy(URI uri);
- /** Whether to gzip request bodies; default false */
- FeedClientBuilder setGzipRequests(boolean gzip);
+ /** What compression to use for request bodies; default {@code NONE}. */
+ FeedClientBuilder setCompression(Compression compression);
+
+ enum Compression { none, gzip }
/** Constructs instance of {@link FeedClient} from builder configuration */
FeedClient build();